@@ -1,3 +1,4 @@
+import slimbook.kbd
 
 from gi.repository import Gdk, Gtk, GdkPixbuf
 from os.path import expanduser
@@ -28,16 +29,18 @@ class Grid(Gtk.Grid):
         self.switch1.set_halign(Gtk.Align.END)
         self.switch1.set_active(self.get_average_rgb() > 0)
 
+        self.max_brightness = slimbook.kbd.brightness_max(0)
+        
         self.scale = Gtk.Scale.new_with_range(
-            orientation=Gtk.Orientation.HORIZONTAL,
-            min=0,
-            max=100,
-            step=1
+            orientation = Gtk.Orientation.HORIZONTAL,
+            min = 0,
+            max = self.max_brightness,
+            step = 1
         )
         self.scale.connect("button-release-event", self.on_brightness_change)
         self.scale.set_sensitive(self.switch1.get_active())
 
-        self.scale.set_value(self.brightness*100)
+        self.scale.set_value(self.brightness)
         self.switch1.connect("state-set", self.on_switch_change)
         
         label1 = Gtk.Label(label=_("Light switch"))
@@ -112,10 +115,10 @@ class Grid(Gtk.Grid):
 
     def on_draw(self, widget, ctx):
 
-        br = self.brightness
-        r = (self.backlight_red * br) / 0xff
-        g = (self.backlight_green * br) / 0xff
-        b = (self.backlight_blue * br) / 0xff
+        
+        r = (self.backlight_red) / 0xff
+        g = (self.backlight_green) / 0xff
+        b = (self.backlight_blue) / 0xff
         
         w = widget.get_allocated_width()
         h = widget.get_allocated_height()
@@ -138,22 +141,18 @@ class Grid(Gtk.Grid):
         self.scale.set_sensitive(state)
         
         if (not state):
-            self.backlight_red = 0
-            self.backlight_green = 0
-            self.backlight_blue = 0
+            self.brightness = 0
             
             self.write_backlight()
         else:
-            self.backlight_red = 0xff
-            self.backlight_green = 0xff
-            self.backlight_blue = 0xff
+            self.brightness = self.max_brightness
             
             self.write_backlight()
         
         self.sample.queue_draw()
     
     def on_brightness_change(self, widget, value):
-        self.brightness = self.scale.get_value()/100.0
+        self.brightness = self.scale.get_value()
         self.sample.queue_draw()
         self.write_backlight()
     
@@ -168,30 +167,28 @@ class Grid(Gtk.Grid):
         self.write_backlight()
     
     def read_backlight(self):
-        output = subprocess.getoutput('slimbookctl get-kbd-backlight')
-        value = int(output,16)
-        
-        self.backlight_red = (value & 0xff0000) >> 16
-        self.backlight_green = (value & 0x00ff00) >> 8
-        self.backlight_blue = value & 0x0000ff
-        
-        self.brightness = self.get_max_brightness()/0xff
     
+        output = subprocess.getoutput('slimbookctl get-kbd-backlight')
+        color = int(output,16)
+        
+        self.backlight_red = (color & 0xff0000) >> 16
+        self.backlight_green = (color & 0x00ff00) >> 8
+        self.backlight_blue = color & 0x0000ff
+        
+        output = subprocess.getoutput('slimbookctl get-kbd-brightness')
+        self.brightness = int(output,16)
+        
     def write_backlight(self):
-        br = self.brightness
-        r = int(self.backlight_red * br)
-        g = int(self.backlight_green * br)
-        b = int(self.backlight_blue * br)
+        br = int(self.brightness)
+        r = int(self.backlight_red)
+        g = int(self.backlight_green)
+        b = int(self.backlight_blue)
         
         value = (r<<16) | (g<<8) | b
+        
         subprocess.getoutput('slimbookctl set-kbd-backlight {0:06x}'.format(value))
-            
+        subprocess.getoutput('slimbookctl set-kbd-brightness {0:06x}'.format(br))
+    
     def get_average_rgb(self):
         return (self.backlight_red + self.backlight_green + self.backlight_blue) / 3.0
 
-    def get_max_brightness(self):
-        top = max(self.backlight_red,self.backlight_green)
-        top = max(top,self.backlight_blue)
-        
-        return top
-
